==> nvidia-graphics-drivers-535-server_535.54.03.orig-kernelsrc.tar.gz: NVIDIA-kernel-module-source-535.54.03/src/nvidia/src/kernel/gpu/sec2/arch/hopper/kernel_sec2_gh100.c <==
/*
 * SPDX-FileCopyrightText: Copyright (c) 2023 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
 * SPDX-License-Identifier: MIT
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

#include "gpu/sec2/kernel_sec2.h"
#include "gpu/conf_compute/conf_compute.h"

#include "core/core.h"

NV_STATUS
ksec2StateLoad_GH100
(
    OBJGPU *pGpu,
    KernelSec2 *pKernelSec2,
    NvU32 unused
)
{
    ConfidentialCompute *pConfCompute = GPU_GET_CONF_COMPUTE(pGpu);
    if ((pConfCompute != NULL) &&
        (pConfCompute->getProperty(pCC, PDB_PROP_CONFCOMPUTE_CC_FEATURE_ENABLED)))
    {
        NV_STATUS status = confComputeDeriveSecrets_HAL(pConfCompute, MC_ENGINE_IDX_SEC2);
        NV_PRINTF(LEVEL_ERROR, "Failed to derive sec2 key secrets with error 0x%x\n", status);
        // TODO: Return error when this fails once confComputeDeriveSecrets_HAL is enabled for all chips
    }
    return NV_OK;
}

==> nvidia-graphics-drivers-535-server_535.261.03.orig-kernelsrc.tar.gz: NVIDIA-kernel-module-source-535.261.03/src/nvidia/src/kernel/gpu/sec2/arch/hopper/kernel_sec2_gh100.c <==
/*
 * SPDX-FileCopyrightText: Copyright (c) 2023 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
 * SPDX-License-Identifier: MIT
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

#include "gpu/sec2/kernel_sec2.h"
#include "gpu/conf_compute/conf_compute.h"
#include "conf_compute/cc_keystore.h"

#include "core/core.h"

NV_STATUS
ksec2StateLoad_GH100
(
    OBJGPU *pGpu,
    KernelSec2 *pKernelSec2,
    NvU32 unused
)
{
    ConfidentialCompute *pConfCompute = GPU_GET_CONF_COMPUTE(pGpu);

    if ((pConfCompute != NULL) &&
        (pConfCompute->getProperty(pCC, PDB_PROP_CONFCOMPUTE_CC_FEATURE_ENABLED)))
    {
        NV_ASSERT_OK_OR_RETURN(confComputeDeriveSecrets_HAL(pConfCompute, MC_ENGINE_IDX_SEC2));
    }
    return NV_OK;
}
